@@ -98,7 +98,7 @@ audio_file_open(const struct vfsref *vr)
 
 	out = g_slice_new0(struct audio_file);
 	
-	out->fp = vfs_handle(vr);
+	out->fp = vfs_open(vr);
 	if (out->fp == NULL)
 		goto bad;
 
@@ -143,7 +143,9 @@ audio_file_close(struct audio_file *fd)
 
 	g_free(fd->artist);
 	g_free(fd->title);
+#ifdef BUILD_SCROBBLER
 	g_free(fd->album);
+#endif /* BUILD_SCROBBLER */
 	g_slice_free(struct audio_file, fd);
 }
 
