@@ -242,7 +242,7 @@ done:
 }
 
 void
-playq_init(int xmms, int load_dumpfile)
+playq_init(int autoplay, int xmms, int load_dumpfile)
 {
 	const char *filename;
 	struct vfsref *vr;
@@ -251,6 +251,9 @@ playq_init(int xmms, int load_dumpfile)
 	playq_wakeup = g_cond_new();
 	playq_rand = g_rand_new(); /* XXX: /dev/urandom in chroot() */
 
+	if (autoplay || config_getopt_bool("playq.autoplay"))
+		playq_flags &= ~PF_STOP;
+
 	if (xmms || config_getopt_bool("playq.xmms")) {
 		funcs = &xmms_funcs;
 		playq_repeat = 1;
@@ -259,7 +262,7 @@ playq_init(int xmms, int load_dumpfile)
 	filename = config_getopt("playq.dumpfile");
 	if (load_dumpfile && filename[0] != '\0') {
 		/* Autoload playlist */
-		vr = vfs_open(filename, NULL, NULL, 0);
+		vr = vfs_lookup(filename, NULL, NULL, 0);
 		if (vr != NULL) {
 			vfs_unfold(&playq_list, vr);
 			vfs_close(vr);
@@ -307,9 +310,12 @@ playq_shutdown(void)
 void
 playq_song_add_head(struct vfsref *vr)
 {
-	/* Recursively expand the item */
 	struct vfslist newlist = VFSLIST_INITIALIZER;
+
+	/* Recursively expand the item */
 	vfs_unfold(&newlist, vr);
+	if (vfs_list_empty(&newlist))
+		return;
 
 	playq_lock();
 	/* Copy the expanded contents to the playlist */
@@ -327,9 +333,12 @@ playq_song_add_head(struct vfsref *vr)
 void
 playq_song_add_tail(struct vfsref *vr)
 {
-	/* Recursively expand the item */
 	struct vfslist newlist = VFSLIST_INITIALIZER;
+
+	/* Recursively expand the item */
 	vfs_unfold(&newlist, vr);
+	if (vfs_list_empty(&newlist))
+		return;
 
 	playq_lock();
 	/* Copy the expanded contents to the playlist */
@@ -434,9 +443,12 @@ void
 playq_song_fast_add_before(struct vfsref *nvr, struct vfsref *lvr,
     unsigned int index)
 {
-	/* Recursively expand the item */
 	struct vfslist newlist = VFSLIST_INITIALIZER;
+
+	/* Recursively expand the item */
 	vfs_unfold(&newlist, nvr);
+	if (vfs_list_empty(&newlist))
+		return;
 
 	/* Copy the expanded contents to the playlist */
 	while ((nvr = vfs_list_first(&newlist)) != NULL) {
@@ -453,9 +465,12 @@ void
 playq_song_fast_add_after(struct vfsref *nvr, struct vfsref *lvr,
     unsigned int index)
 {
-	/* Recursively expand the item */
 	struct vfslist newlist = VFSLIST_INITIALIZER;
+
+	/* Recursively expand the item */
 	vfs_unfold(&newlist, nvr);
+	if (vfs_list_empty(&newlist))
+		return;
 
 	/* Copy the expanded contents to the playlist */
 	while ((nvr = vfs_list_last(&newlist)) != NULL) {
@@ -528,7 +543,7 @@ playq_song_fast_move_tail(struct vfsref *vr, unsigned int index)
 }
 
 void
-playq_song_fast_select(struct vfsref *vr, unsigned int index)
+playq_song_fast_select(struct vfsref *vr)
 {
 	if (funcs->select(vr) != 0)
 		return;
