@@ -53,10 +53,12 @@ vfs_xspf_populate(struct vfsent *ve)
 	struct spiff_list *slist;
 	struct spiff_track *strack;
 	struct spiff_mvalue *sloc;
-	char *dirname, *filename;
+	char *dirname, *baseuri, *filename;
 	struct vfsref *vr;
 
-	slist = spiff_parse(ve->filename);
+	baseuri = url_escape(ve->filename);
+	slist = spiff_parse(ve->filename, baseuri);
+	g_free(baseuri);
 	if (slist == NULL)
 		return (-1);
 
@@ -85,7 +87,7 @@ vfs_xspf_write(const struct vfslist *vl, const char *filename)
 	struct spiff_list *list;
 	struct spiff_track *track;
 	struct spiff_mvalue *location;
-	char *fn;
+	char *fn, *baseuri;
 	struct vfsref *vr;
 	int ret;
 
@@ -94,7 +96,10 @@ vfs_xspf_write(const struct vfslist *vl, const char *filename)
 	VFS_LIST_FOREACH_REVERSE(vl, vr) {
 		/* Add a new track to the beginning of the list */
 		track = spiff_new_track_before(&list->tracks);
-		spiff_setvalue(&track->title, vfs_name(vr));
+
+		/* Make sure we don't write non-UTF-8 titles to disk */
+		if (g_utf8_validate(vfs_name(vr), -1, NULL))
+			spiff_setvalue(&track->title, vfs_name(vr));
 
 		location = spiff_new_mvalue_before(&track->locations);
 		fn = url_escape(vfs_filename(vr));
@@ -102,7 +107,9 @@ vfs_xspf_write(const struct vfslist *vl, const char *filename)
 		g_free(fn);
 	}
 
-	ret = spiff_write(list, filename);
+	baseuri = url_escape(filename);
+	ret = spiff_write(list, filename, baseuri);
+	g_free(baseuri);
 	spiff_free(list);
 
 	return (ret);
